@@ -18,7 +18,7 @@ class AdresseParser():
     def __init__(self):
         self.regex_rue = '((AVENUE|IMPASSE|QUAI|VOIE|RUELLE|PLACE|BOULEVARD|RUE|VOIE|CIT(E|É)|ALL(É|E)E|CHEMIN|ROUTE|GR|R(É|E)SIDENCE|HAMEAU|LIEU(-| )DIT|TRAVERSE|PROMENADE|ROND(-| )POINT|PASSAGE)( D(E(S?| LA)|U))? )'
         self.type_rue = ['rue', 'avenue', 'boulevard', 'impasse', 'quai', 'voie', 'place', 'ruelle', 'cour', 'cité', 'cite', 'allée','allee','chemin','lieu-dit','promenade','lieu dit','rond point', 'rond-point', 'passage','traverse','route','gr','résidence','residence','hameau']
-        self.cedex = pd.read_csv('AdresseParser/data/liste-des-cedex.csv', delimiter=";")
+        self.cedex = pd.read_csv('AdresseParser/liste-des-cedex.csv', delimiter=";")
 
     def parse(self, adresse_string):
         """
